"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.check = check;

var _globby = _interopRequireDefault(require("globby"));

var fs = _interopRequireWildcard(require("fs-extra"));

var path = _interopRequireWildcard(require("path"));

var _getWorkspaceInfo = _interopRequireDefault(require("./utils/getWorkspaceInfo"));

var _isModularType = require("./utils/isModularType");

var logger = _interopRequireWildcard(require("./utils/logger"));

var _getModularRoot = _interopRequireDefault(require("./utils/getModularRoot"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

async function check() {
  var _rootPackageJson$work;

  let failed = false;
  const modularRoot = (0, _getModularRoot.default)();
  const rootPackageJsonPath = path.join(modularRoot, 'package.json');
  const rootPackageJson = await fs.readJSON(rootPackageJsonPath);

  if (!rootPackageJson.private) {
    logger.error(`Modular workspace roots must be marked as private`);
    failed = true;
  }

  if (!(rootPackageJson !== null && rootPackageJson !== void 0 && (_rootPackageJson$work = rootPackageJson.workspaces) !== null && _rootPackageJson$work !== void 0 && _rootPackageJson$work.includes('packages/**'))) {
    logger.error(`Modular workspaces must include "packages/**" to pick up any modular packages in the worktree`);
    failed = true;
  } // ensure that workspaces are setup correctly with yarn
  // init is a special case where we don't already need to be in a modular repository
  // in this case there's no use checking the workspaces yet because we're setting
  // up a new folder


  const workspace = await (0, _getWorkspaceInfo.default)();
  /**
   * Validate the structure of the workspace to ensure there's no mismatched dependencies and that
   * all the workspaces are valid modular package types.
   */

  for (const [packageName, packageInfo] of Object.entries(workspace)) {
    if (packageInfo.mismatchedWorkspaceDependencies.length) {
      logger.error(`${packageName} has mismatchedWorkspaceDependencies ${packageInfo.mismatchedWorkspaceDependencies.join(', ')}`);
      failed = true;
    }

    if (!packageInfo.location.startsWith('packages')) {
      logger.error(`${packageName} is not located within the "/packages" directory in the repository, instead found "${packageInfo.location}"`);
      failed = true;
    }

    if (!(0, _isModularType.isValidModularType)(path.join(modularRoot, packageInfo.location))) {
      logger.error(`${packageName} at ${packageInfo.location} is not a valid modular type - Found ${(0, _isModularType.getModularType)(packageInfo.location)}`);
      failed = true;
    }

    if (packageInfo.type === 'app') {
      if (packageInfo.public) {
        logger.error(`${packageName} is marked as "public" - Modular apps should be marked as private.`);
        failed = true;
      }
    }

    logger.debug(`${packageName} is valid.`);
  }
  /**
   * Validate the the worktrree is valid against the globby of pacakge.json files which are found in the
   * current working directory. They should be the same but you never know...
   */


  const workspaces = Object.values(workspace).map(w => w.location);
  const workspaceLocations = (await (0, _globby.default)(['packages/**/package.json', '!**/node_modules/**'], {
    onlyFiles: true,
    cwd: modularRoot
  })).map(l => path.dirname(l));
  workspaces.forEach(workspaceLocation => {
    const overlapping = workspaceLocations.filter(otherWorkspaceLocation => {
      // obviously workspaces which are the same can't be overlapping
      const relative = path.relative(workspaceLocation, otherWorkspaceLocation);
      return relative && !relative.startsWith('..') && !path.isAbsolute(relative);
    });

    if (overlapping.length) {
      logger.error(`Found ${workspaceLocation} which is an overlapping workspace with ${overlapping.join(', ')} in your current worktree`);
      failed = true;
    }
  });
  const {
    verifyPackageTree
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./utils/verifyPackageTree')));
  failed = await verifyPackageTree();

  if (failed) {
    throw new Error(`The above errors were found during modular check`);
  }
}