"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = build;

var esbuild = _interopRequireWildcard(require("esbuild"));

var _isCi = _interopRequireDefault(require("is-ci"));

var _chalk = _interopRequireDefault(require("chalk"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var minimize = _interopRequireWildcard(require("html-minifier-terser"));

var path = _interopRequireWildcard(require("path"));

var _getClientEnvironment = _interopRequireDefault(require("../config/getClientEnvironment"));

var logger = _interopRequireWildcard(require("../../utils/logger"));

var _formatError = require("../utils/formatError");

var _svgr = _interopRequireDefault(require("../plugins/svgr"));

var _api = require("../api");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const plugins = [(0, _svgr.default)()];

async function build(target, paths) {
  const env = (0, _getClientEnvironment.default)(paths.publicUrlOrPath.slice(0, -1));
  const html = await (0, _api.createIndex)(paths, env.raw, false);
  await _fsExtra.default.writeFile(path.join(paths.appBuild, 'index.html'), minimize.minify(html, {
    html5: true,
    collapseBooleanAttributes: true,
    collapseWhitespace: true,
    collapseInlineTagWhitespace: true,
    decodeEntities: true,
    minifyCSS: true,
    minifyJS: true,
    removeAttributeQuotes: true,
    removeComments: true,
    removeTagWhitespace: true
  }));

  try {
    await esbuild.build({
      entryPoints: [paths.appIndexJs],
      plugins,
      bundle: true,
      watch: false,
      resolveExtensions: paths.moduleFileExtensions.map(extension => `.${extension}`),
      sourcemap: true,
      loader: {
        // loaders for images which are supported as files
        '.avif': 'file',
        '.bmp': 'file',
        '.gif': 'file',
        '.jpg': 'file',
        '.jpeg': 'file',
        '.png': 'file',
        '.webp': 'file',
        // enable JSX in js files
        '.js': 'jsx'
      },
      logLevel: 'silent',
      target: 'es2015',
      absWorkingDir: paths.appPath,
      format: 'esm',
      color: !_isCi.default,
      define: (0, _getClientEnvironment.default)(paths.publicUrlOrPath).stringified,
      metafile: true,
      tsconfig: paths.appTsConfig,
      minify: true,
      outbase: 'src',
      outdir: paths.appBuild,
      publicPath: paths.publicUrlOrPath,
      nodePaths: (process.env.NODE_PATH || '').split(path.delimiter)
    });
  } catch (e) {
    const result = e;
    logger.log(_chalk.default.red('Failed to compile.\n'));
    const logs = result.errors.map(async m => {
      logger.log(await (0, _formatError.formatError)(m));
    });
    await Promise.all(logs);
    throw new Error(`Failed to build ${target}`);
  }
}