"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkBrowsers = checkBrowsers;
exports.defaultBrowsers = void 0;

var _browserslist = _interopRequireDefault(require("browserslist"));

var _chalk = _interopRequireDefault(require("chalk"));

var os = _interopRequireWildcard(require("os"));

var _prompts = _interopRequireDefault(require("prompts"));

var fs = _interopRequireWildcard(require("fs-extra"));

var _pkgUp = _interopRequireDefault(require("pkg-up"));

var logger = _interopRequireWildcard(require("./logger"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultBrowsers = {
  production: ['>0.2%', 'not dead', 'not op_mini all'],
  development: ['last 1 chrome version', 'last 1 firefox version', 'last 1 safari version']
};
exports.defaultBrowsers = defaultBrowsers;

async function shouldSetBrowsers() {
  if (!process.stdout.isTTY) {
    return Promise.resolve(true);
  }

  const answer = await (0, _prompts.default)({
    type: 'confirm',
    name: 'shouldSetBrowsers',
    message: _chalk.default.yellow("We're unable to detect target browsers.") + `\n\nWould you like to add the defaults to your ${_chalk.default.bold('package.json')}?`,
    initial: true
  });
  return answer.shouldSetBrowsers;
}

async function checkBrowsers(dir, retry = true) {
  const current = _browserslist.default.loadConfig({
    path: dir
  });

  if (current != null) {
    return Promise.resolve();
  }

  if (!retry) {
    return Promise.reject(new Error(_chalk.default.red('As of react-scripts >=2 you must specify targeted browsers.') + os.EOL + `Please add a ${_chalk.default.underline('browserslist')} key to your ${_chalk.default.bold('package.json')}.`));
  }

  const shouldUpdateBrowser = await shouldSetBrowsers();

  if (!shouldUpdateBrowser) {
    return checkBrowsers(dir, false);
  }

  const filePath = await (0, _pkgUp.default)({
    cwd: dir
  });

  if (filePath == null) {
    return checkBrowsers(dir, false);
  } else {
    const pkg = await fs.readJson(filePath);
    pkg['browserslist'] = defaultBrowsers;
    await fs.writeJson(filePath, pkg, {
      spaces: 2
    });

    _browserslist.default.clearCaches();

    logger.log();
    logger.log(`${_chalk.default.green('Set target browsers:')} ${_chalk.default.cyan(JSON.stringify(defaultBrowsers, null, 2))}`);
    logger.log();
  }
}